@@ -9,6 +9,7 @@
 # $2: comma separated groups
 # $3: comma separated pools
 # $4: region
+# $5: minimum supported deadline version
 
 # exit when any command fails
 set -xeuo pipefail
@@ -17,6 +18,7 @@ HEALTH_CHECK_PORT="$1"
 WORKER_GROUPS=(${2//,/ })
 WORKER_POOLS=(${3//,/ })
 WORKER_REGION="$4"
+MINIMUM_SUPPORTED_DEADLINE_VERSION=$5
 
 # Cloud-init does not load system environment variables. Cherry-pick the
 # environment variable installed by the Deadline Client installer.
@@ -36,6 +38,21 @@ if [ ! -f "$DEADLINE_COMMAND" ]; then
     exit 1
 fi
 
+isVersionLessThan() {
+    python -c "import sys;sys.exit(0 if tuple(map(int, sys.argv[-2].split('.'))) < tuple(map(int, sys.argv[-1].split('.'))) else 1)" "$1" "$2"
+}
+
+DEADLINE_VERSION=$("$DEADLINE_COMMAND" -Version | grep -oP '[v]\K\d+\.\d+\.\d+\.\d+\b')
+if [ -z "$DEADLINE_VERSION" ]; then
+    echo "ERROR: Unable to identify the version of installed Deadline Client. Exiting..."
+    exit 1
+fi
+
+if isVersionLessThan $DEADLINE_VERSION $MINIMUM_SUPPORTED_DEADLINE_VERSION; then
+    echo "ERROR: Installed Deadline Version ($DEADLINE_VERSION) is less than the minimum supported version ($MINIMUM_SUPPORTED_DEADLINE_VERSION). Exiting..."
+    exit 1
+fi
+
 # launch worker at launcher startup
 "$DEADLINE_COMMAND" -SetIniFileSetting LaunchSlaveAtStartup True
 # keep worker running
