@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.assets._jsii
 import aws_cdk.aws_apigateway._jsii
@@ -62,7 +62,7 @@ import aws_cdk.region_info._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "aws-rfdk", "0.17.0", __name__[0:-6], "aws-rfdk@0.17.0.jsii.tgz"
+    "aws-rfdk", "0.18.1", __name__[0:-6], "aws-rfdk@0.18.1.jsii.tgz"
 )
 
 __all__ = [
